Cop1Access

Enum Cop1Access 

pub enum Cop1Access {
    ReadFpr {
        src: u8,
        dest: u8,
        wide: bool,
    },
    WriteFpr {
        dest: u8,
        value: u64,
        wide: bool,
    },
    Arith {
        fmt: u8,
        funct: u8,
        ft: u8,
        fs: u8,
        fd: u8,
    },
    ReadControl {
        src: u8,
        dest: u8,
    },
    WriteControl {
        dest: u8,
        value: u32,
    },
}
The COP1 control moves (T-12-006). Arithmetic is Sprint 3.

Variants



ReadFpr

MFC1/DMFC1 — move an FPR to a GPR.

Fields

src: u8

FPR number (fs).

dest: u8

GPR destination.

wide: bool

64-bit (DMFC1) rather than 32-bit sign-extended (MFC1).



WriteFpr

MTC1/DMTC1 — move a GPR to an FPR.

Fields

dest: u8

FPR number (fs).

value: u64

Value from rt.

wide: bool

64-bit (DMTC1) rather than 32-bit (MTC1).



Arith

A COP1 arithmetic operation, performed by the pipeline because it reads two FPRs and writes a third, and execute has no FPR access.

Fields

fmt: u8

Format from rs: 16 = single, 17 = double.

funct: u8

Operation from funct.

ft: u8

Second source FPR.

fs: u8

First source FPR.

fd: u8

Destination FPR.



ReadControl

CFC1 — read control register src into GPR dest.

Fields

src: u8

COP1 control register number.

dest: u8

GPR destination.



WriteControl

CTC1 — write value to control register dest.

Fields

dest: u8

COP1 control register number.

value: u32

Value from rt.