lwl

Function lwl 

pub const fn lwl(rt: u64, word: u32, byte: u64) -> u64
LWL — merge the bytes from the addressed byte to the end of the containing word into the top of rt, preserving rt’s low bytes.

word is the aligned word containing addr; byte is addr & 3. Big-endian, so byte offset 0 selects the most-significant byte.