pub const fn block_order(width: Width, addr: u32) -> BlockOrderExpand description
The ordering a read of width at addr uses.
D-cache 128-bit reads are sub-block ordered when address bit 4 is set; everything else, including all I-cache 256-bit reads, is sequential. Getting this wrong corrupts every other cache line fill and nothing else.