pub enum Cop1Access {
ReadFpr {
src: u8,
dest: u8,
wide: bool,
},
WriteFpr {
dest: u8,
value: u64,
wide: bool,
},
Arith {
fmt: u8,
funct: u8,
ft: u8,
fs: u8,
fd: u8,
},
ReadControl {
src: u8,
dest: u8,
},
WriteControl {
dest: u8,
value: u32,
},
}Expand description
The COP1 control moves (T-12-006). Arithmetic is Sprint 3.
Variants
ReadFpr
MFC1/DMFC1 — move an FPR to a GPR.
Fields
WriteFpr
MTC1/DMTC1 — move a GPR to an FPR.
Fields
Arith
A COP1 arithmetic operation, performed by the pipeline because it reads
two FPRs and writes a third, and execute has no FPR access.
Fields
ReadControl
CFC1 — read control register src into GPR dest.
WriteControl
CTC1 — write value to control register dest.